#ifndef __CF_FLAGS_H__
#define __CF_FLAGS_H__

#include <Core/CFDefines.h>
#include <Core/CFTypes.h>

class CF_EXPORT CFFlag
{
    int i;
public:
    inline CFFlag(int i);
    inline operator int() const { return i; }
};

inline CFFlag::CFFlag(int ai) : i(ai) {}

template<typename Enum>
class CFFlags
{
    int i;
public:
    typedef Enum enum_type;
    CF_DECL_CONSTEXPR inline CFFlags(const CFFlags &f) : i(f.i) {}
    CF_DECL_CONSTEXPR inline CFFlags(Enum f) : i(f) {}
    CF_DECL_CONSTEXPR inline CFFlags(CFInt f) : i(f) {}
    CF_DECL_CONSTEXPR inline CFFlags() : i(0) {}
    inline CFFlags(CFFlag f) : i(f) {}

    inline CFFlags &operator=(const CFFlags &f) { i = f.i; return *this; }
    inline CFFlags &operator&=(CFInt mask) { i &= mask; return *this; }
    inline CFFlags &operator&=(CFUInt mask) { i &= mask; return *this; }
    inline CFFlags &operator|=(CFFlags f) { i |= f.i; return *this; }
    inline CFFlags &operator|=(Enum f) { i |= f; return *this; }
    inline CFFlags &operator^=(CFFlags f) { i ^= f.i; return *this; }
    inline CFFlags &operator^=(Enum f) { i ^= f; return *this; }

    CF_DECL_CONSTEXPR  inline operator int() const { return i; }

    CF_DECL_CONSTEXPR inline CFFlags operator|(CFFlags f) const { return CFFlags(Enum(i | f.i)); }
    CF_DECL_CONSTEXPR inline CFFlags operator|(Enum f) const { return CFFlags(Enum(i | f)); }
    CF_DECL_CONSTEXPR inline CFFlags operator^(CFFlags f) const { return CFFlags(Enum(i ^ f.i)); }
    CF_DECL_CONSTEXPR inline CFFlags operator^(Enum f) const { return CFFlags(Enum(i ^ f)); }
    CF_DECL_CONSTEXPR inline CFFlags operator&(int mask) const { return CFFlags(Enum(i & mask)); }
    CF_DECL_CONSTEXPR inline CFFlags operator&(uint mask) const { return CFFlags(Enum(i & mask)); }
    CF_DECL_CONSTEXPR inline CFFlags operator&(Enum f) const { return CFFlags(Enum(i & f)); }
    CF_DECL_CONSTEXPR inline CFFlags operator~() const { return CFFlags(Enum(~i)); }

    CF_DECL_CONSTEXPR inline bool operator!() const { return !i; }

    inline bool testFlag(Enum f) const { return (i & f) == f && (f != 0 || i == int(f) ); }
};

#define CF_DECLARE_FLAGS(Flags, Enum)\
typedef CFFlags<Enum> Flags;

#endif // __CF_FLAGS_H__