﻿#ifndef __CF_TIMER_H__
#define __CF_TIMER_H__

/**
 * \brief CFTimer 计时器
 *
 * 定时器对象测量经过的时间。
 *
 * 建议实现测量挂钟而不是CPU时间，因为预期用途是在总运行时间比只是进程或CPU时间更重要的
 * 系统上进行性能测量。
 */

#include <ctime>


class CFTimer
{	
public:
    /**
     * 创建一个CFTimer实例
     *
     */
	CFTimer();

    /**
     * 销毁一个CFTimer实例
     */
	~CFTimer();

    /**
     * 在time变为0之前，重启
     *
     */
	void restart();

    /**
     * 函数简单地测量自对象创建后所流逝的时间。
     *
     * @see restart()
     * @return double 秒数
     */
    double elapsed() const;

    /**
     * get the estimated maxinum time for elapsed()
     *
     * @see elapsed_min()
     * @return the maxinum value for elapsed()
     */
	double elapsedMax() const;

    /**
     * get the estimated mininum time for elapsed()
     *
     * @see elapsed_max()
     * @return the mininum value for elapsed()
     */
	double elapsedMin() const;

private:
	std::clock_t m_time;

}; //timer


#endif //__CF_TIMER_H__
