// Copyright 2017, CDOS.
// All rights reserved.
//
// Author: CDOS Support Team <support_os@sari.ac.cn>
//
// A class representing an adjustable bounded value.

/**
 * \file 调整对象类
 */

/**
 * \brief 可调整有界值的类
 *
 *  CFAdjustment
 * 对象表示具有相关联的下限和上限以及步长和页面增量以及页面大小的值。
 * 它在几个小部件中使用，包括CFRange(它是 CFSCrollbar, CFScale 的基类)等。\n
 * CFAdjustment 对象不会更新本身值。相反，它由CFAdjustment的所有者控制。
 */

#ifndef __CF_ADJUSTMENT_H__
#define __CF_ADJUSTMENT_H__
#include <Core/CFObject.h>

CF_NAMESPACE_BEGIN

class CFAdjustment : public CFObject {
public:
    virtual ~CFAdjustment();

    CFAdjustment(double value,
                 double lower,
                 double upper,
                 double step_increment = 1,
                 double page_increment = 10,
                 double page_size = 0);

    void changed();

    void valueChanged();

    void clampPage(double lower, double upper);

    void setValue(double value);

    double getValue();

    void setLower(double lower);

    double getLower();

    void setUpper(double upper);

    double getUpper();

    void setStepIncrement(double step_increment);

    double getStepIncrement();

    void setPageIncrement(double page_increment);

    double getPageIncrement();

    void setPageSize(double page_size);

    double getPageSize();

    void configure(double value,
                   double lower,
                   double upper,
                   double step_increment,
                   double page_increment,
                   double page_size);

    double getMinimumIncrement();

    static CFAdjustment* create(double value,
                                double lower,
                                double upper,
                                double step_increment = 1,
                                double page_increment = 10,
                                double page_size = 0);

    sigc::signal<void> signalChanged();
    sigc::signal<void> signalValueChanged();

protected:
    virtual void onRealObjectInit();
    virtual void onRealObjectFinalize();

    virtual void onChanged();
    virtual void onValueChanged();

private:
    sigc::signal<void> m_changedSignal;
    sigc::signal<void> m_changedValueSignal;
};

CF_NAMESPACE_END
#endif  // __CF_ADJUSTMENT_H__
