#ifndef __CF_ENUMS_H__
#define __CF_ENUMS_H__

#include <Core/CFDefines.h>

CF_NAMESPACE_BEGIN

/** \addtogroup 结构与枚举类型定义
   @{ */

/**
 * \enum CFWindowType
 * 表示CFWindow的类型
 *
 */
typedef enum {
    CFWINDOW_TOPLEVEL = 0,  ///< 一种普通的window，例如对话框
    CFWINDOW_POPUP  ///< 某些特别的window，例如提示框
} CFWindowType;

/**
 * \enum CFOrientation
 * 表示控件或者其他对象的呈现方向，可以在水平和垂直之间切换
 */
typedef enum {
    CFORIENTATION_HORIZONTAL = 0,  ///< 水平方向
    CFORIENTATION_VERTICAL  ///< 垂直方向
} CFOrientation;

/**
 * \enum CFAlign
 * 在水平或者垂直方向上，控制控件如何处理额外的空间
 *
 */
typedef enum {
    CFALIGN_FILL = 0,  ///< 尽可能拉伸来填充空间，如果无意义的对其方式就居中
    CFALIGN_START,  ///< 紧靠着左边或上边，对右边或下边预留空间
    CFALIGN_END,  ///< 紧靠着右边或下边，对左边或上边预留空间
    CFALIGN_CENTER,  ///< 在所处控件中，根据宽度居中
    CFALIGN_BASELINE  ///< 根据基准线对其控件
} CFAlign;

/**
 * \enum CFReliefStyle
 * 按钮（CFButton）的浮雕效果样式。
 */
typedef enum {
    CFRELIEF_NORMAL = 0,  ///< 正常的浮雕效果
    CFRELIEF_HALF,  ///< 轻微浮雕效果<br>已经废弃，与CFRELIEF_NORMAL同样效果
    CFRELIEF_NONE  ///< 无浮雕效果
} CFReliefStyle;

/**
 * \enum CFStackTransitionType
 * 动画类型
 */
typedef enum {
    CFSTACK_TRANSITION_TYPE_NONE = 0,  ///< 无动画
    CFSTACK_TRANSITION_TYPE_CROSSFADE,  ///< 淡入淡出
    CFSTACK_TRANSITION_TYPE_SLIDE_RIGHT,  ///< 从左向右滑入
    CFSTACK_TRANSITION_TYPE_SLIDE_LEFT,  ///< 从右向左滑入
    CFSTACK_TRANSITION_TYPE_SLIDE_UP,  ///< 从下到上滑入
    CFSTACK_TRANSITION_TYPE_SLIDE_DOWN,  ///< 从上倒下滑入
    /**
     * 根据孩子的顺序从左滑入或从右滑入
     */
    CFSTACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT,
    CFSTACK_TRANSITION_TYPE_SLIDE_UP_DOWN  ///< 根据孩子的顺序从上滑入或从下滑入
} CFStackTransitionType;

/**
 * \enum CFPositionType
 * 描述控件的边缘位置
 */
typedef enum {
    CFPOS_LEFT = 0,  ///< 左边界
    CFPOS_RIGHT,  ///< 右边界
    CFPOS_TOP,  ///< 上边界
    CFPOS_BOTTOM  ///< 下边界
} CFPositionType;

/**
 * \enum CFBuiltinIconSize
 * cdos-fw 内建的图标尺寸
 */
typedef enum {
    CFICON_SIZE_INVALID,  ///< 不合法的尺寸
    CFICON_SIZE_MENU,  ///< 适用于menu的尺寸（16px）
    CFICON_SIZE_SMALL_TOOLBAR,  ///< 适用于小工具栏尺寸（16px）
    CFICON_SIZE_LARGE_TOOLBAR,  ///< 适用于大工具栏尺寸（24px）
    CFICON_SIZE_BUTTON,  ///< 适用于Button的图标尺寸（16px）
    CFICON_SIZE_DND,  ///< 适用于拖拽的图标尺寸（32px）
    CFICON_SIZE_DIALOG  ///< 适用于对话框的图标尺寸（48px）
} CFBuiltinIconSize;


/**
 * \enum CFJustification
 * 在CFLabel中文本的对齐方式
 */
typedef enum {
    CFJUSTIFY_LEFT,  ///< 左对齐
    CFJUSTIFY_RIGHT,  ///< 右对齐
    CFJUSTIFY_CENTER,  ///< 居中对齐
    CFJUSTIFY_FILL  ///< 两端对齐
} CFJustification;


/**
 * \enum CFPolicyType
 * 确定应如何计算大小以实现滚动条的可见性模式
 */
typedef enum {
    CFPOLICY_ALWAYS,  ///< 总是显示
    CFPOLICY_AUTOMATIC,  ///< 自动
    CFPOLICY_NEVER,  ///< 从不显示
    /**
     * 不显示滚动条，但是不限制接下来的内容尺寸
     */
    CFPOLICY_EXTERNAL
} CFPolicyType;


/**
 * \enum CFCornerType
 * 决定子容器应该被放置在 CFScrollWindow 的哪个角落<br>
 * 这个位置是与滚动条相反的。
 */
typedef enum {
    CFCORNER_TOP_LEFT,  ///< 在控件的右侧或底部放置滚动条
    CFCORNER_BOTTOM_LEFT,  ///< 在控件的右侧或顶部放置滚动条
    CFCORNER_TOP_RIGHT,  ///< 在控件的左侧或底部放置滚动条
    CFCORNER_BOTTOM_RIGHT  ///< 在控件的左侧或顶部放置滚动条
} CFCornerType;


/**
 * \enum CFShadowType
 * 通常用于更改轮廓的外观
 */
typedef enum {
    CFSHADOW_NONE,  ///< 无阴影
    CFSHADOW_IN,  ///< 阴影内向
    CFSHADOW_OUT,  ///< 阴影外向
    CFSHADOW_ETCHED_IN,  ///< 阴影向内凹进
    CFSHADOW_ETCHED_OUT  ///< 阴影向外凸进
} CFShadowType;

/**
 * \enum CFPlacesOpenFlags
 * 确定滚动条的展示方式
 *
 * 这个标志位主要有两个目的：<br>
 * 1. 告诉打开的应用可以使用多种滚动条的展示方式<br>
 * 2. 被 CFPlacesSidebar::signal_open_location() 信号所使用
 *
 */
typedef enum {
    CFPLACES_OPEN_NORMAL,  ///< 这是默认模式，正常方式打开
    CFPLACES_OPEN_NEW_TAB,  ///< 新标签页方式打开，应用可以在侧边栏打开文件夹
    /**
     * 与 CFPLACES_OPEN_NEW_TAB 相同，但是能在新窗口中打开文件夹
     */
    CFPLACES_OPEN_NEW_WINDOW
} CFPlacesOpenFlags;

/**
 * \enum CFSelectionMode
 * 用于控制用户可以作出怎样的选择方式
 */
typedef enum {
    CFSELECTION_NONE,  ///< 不可选
    CFSELECTION_SINGLE,  ///< 可选0或1个
    CFSELECTION_BROWSE,  ///< 确定的选择某个元素
    CFSELECTION_MULTIPLE  ///< 多选
} CFSelectionMode;

/**
 * \enum CFPackDirection
 * 确定控件要包含内部的 CFMenuItem 和 CFMenuBar 的方式
 */
typedef enum {
    CFPACK_DIRECTION_LTR,  ///< 控件从左到右摆放
    CFPACK_DIRECTION_RTL,  ///< 控件右从左到摆放
    CFPACK_DIRECTION_TTB,  ///< 控件从上到下摆放
    CFPACK_DIRECTION_BTT  ///< 控件从下到上摆放
} CFPackDirection;

/**
 * \enum CFSensitiveType
 * 确定GTK +如何处理范围部件结束处步进箭头的灵敏度。
 */
typedef enum {
    CFSENSITIVITY_AUTO,  ///< 如果滑块在结尾，箭头不敏感。
    CFSENSITIVITY_ON,  ///< 箭头总是敏感
    CFSENSITIVITY_OFF  ///< 箭头总是不敏感
} CFSensitivityType;

/** @} */

// typedef enum template
// typedef enum {
//     CFSOME_TYPE_,
//     CFSOME_TYPE_,
//     CFSOME_TYPE_
// } CFSomeType;

CF_NAMESPACE_END

#endif // __CF_ENUMS_H__
