// Copyright 2017, CDOS.
// All rights reserved.
//
// Author: CDOS Support Team <support_os@sari.ac.cn>
//
// A container which allows you to position widgets at fixed coordinates.
/**
 * \file
 * 带有坐标设置的容器
 */
#ifndef __CF_FIXED_H__
#define __CF_FIXED_H__

#include "Gui/CFContainer.h"

CF_NAMESPACE_BEGIN

/**
 * \brief 一个容器，允许将控件放置在固定的坐标。
 *
 * Gtk::Fixed控件是一个容器，可以将子窗口控件放置在固定位置，固定大小，以像素为单位。
 * 它不执行自动布局管理。
 * 对于大多数应用程序，您不应该使用此容器，因为它会导致截断的文本，
 * 重叠的小部件和其他显示错误：<br>
 * 1.主题可能改变控件的尺寸<br>
 * 2.应用除了程序字体之外的字体，很可能改变包含文本的控件的大小。请记住，用户可能
 * 使用较大的字体。<br>
 * 3.翻译成其他语言页可能导致文本的尺寸发生改变，进而引发控件大小发生改变。
 */
class CFFixed : public CFContainer {
public:
    /**
     * 默认构造函数.
     */
    CFFixed();

    /**
     * 析构函数.
     *
     * 在 CFSomeType 被销毁时会被自动调用。
     * 在析构函数中进行内存释放等操作。
     */
    ~CFFixed();

    /**
     * 添加控件到 CFFixed 容器中给定的位置。
     *
     * @param [in] widget 要添加的控件
     * @param [in] x 要放置控件的水平位置
     * @param [in] y 要放置控件的垂直位置
     */
    void put(CFWidget& widget, int x, int y);

    /**
     * 设置容器中子控件移动的位置
     *
     * @param [in] widget 子控件
     * @param [in] x 控件要移动的水平位置
     * @param [in] y 控件要移动的竖直位置
     */
    void move(CFWidget& widget, int x, int y);
};

CF_NAMESPACE_END

#endif  // __CF_FIXED_H__
