// Copyright 2017, CDOS.
// All rights reserved.
//
// Author: CDOS Support Team <support_os@sari.ac.cn>
//
// A CFListWidget is a vertical container that contains CFListWidgetItem
// children.

/**
 * \file
 * 列表容器
 */
#ifndef __CF_LISTWIDGET_H__
#define __CF_LISTWIDGET_H__
#include <Gui/CFContainer.h>
#include "Gui/CFListWidgetItem.h"
#include "Gui/CFEnums.h"
#include <vector>

/**
 * \brief CFListWidget 是一个垂直容器。
 *
 * CFListWidget 只能包含 CFListWidgetItem 行对象,
 * 但是 CFListWidgetItem 可以包含多个任何部件，可以根据行内容来排序和过滤。
 *
 * 虽然 CFListWidget 只能包含 CFListWidgetItem 孩子，
 * 但是可以通过 CFContainer.add（） 添加任何小部件到其中，
 * CFListWidgetItem 会自动包裹部件并插入到 CFListWidget 中。
 */

CF_NAMESPACE_BEGIN

class CFListWidgetPriv;

class CFListWidget : public CFContainer {
    friend class CFListWidgetPriv;

public:
    typedef sigc::slot<bool, CFListWidgetItem*> SlotFilter;
    typedef sigc::slot<int, CFListWidgetItem*, CFListWidgetItem*> SlotSort;
    typedef sigc::slot<void, CFListWidgetItem*, CFListWidgetItem*>
        SlotUpdateHeader;
    typedef sigc::slot<void, CFListWidgetItem*> SlotForeach;

    CFListWidget();

    virtual ~CFListWidget();

    void prepend(CFWidget& child);

    void insert(CFWidget& child, int position);

    void append(CFWidget& child);

    CFListWidgetItem* getSelectedItem();

    CFListWidgetItem* getItemAtIndex(int index);

    CFListWidgetItem* getItemAtY(int y);

    void selectItem(CFListWidgetItem& item);

    void unselectItem();

    void unselectItem(CFListWidgetItem* item);

    void setPlaceholder(CFWidget& placeholder);

    void unsetPlaceholder();

    // void setAdjustment();
    // CFAdjustment getAdjustment();

    void selectedForeach(SlotForeach& slot);

    std::vector<CFListWidgetItem*> getSelectItems();

    void selectAll();

    void unselectAll();

    void setSelectionMode(CFSelectionMode mode);

    CFSelectionMode getSelectionMode();

    void setFilterFunc(SlotFilter& slot);

    void unsetFilterFunc();

    void setSortFunc(SlotSort& slot);

    void unsetSortFunc();

    void setHeaderFunc(SlotUpdateHeader& slot);

    void unsetHeaderFunc();

    void invalidateFilter();

    void invalidateSort();

    void setActivateOnSingleClick(bool single = true);

    bool getActiveOnSingleClick();

    void dragUnhighlightItem();

    void dragHighlightItem(CFListWidgetItem& item);

    //     void bindModel(Glib::RefPtr<Gio::ListModel>& model,
    //                     SlotCreateWidget<Glib::Object>& slot_create_widget);
    //
    //     void bindListStore(Glib::RefPtr<Gio::ListStore<T_item>>& store,
    //                          T_slot&& slot_create_widget);

    sigc::signal<void, CFListWidgetItem*> signalItemSelected();

    sigc::signal<void, CFListWidgetItem*> signalItemActivated();

    sigc::signal<void> signalSelectedItemsChanged();

protected:
    virtual void onRealObjectInit();

    virtual void onRealObjectFinalize();

    void onSelectedItemsChanged();

private:
    sigc::signal<void, CFListWidgetItem*> signalForeach();

    sigc::signal<bool, CFListWidgetItem*> signalFilter();

    sigc::signal<int, CFListWidgetItem*, CFListWidgetItem*> signalSort();

    sigc::signal<void, CFListWidgetItem*, CFListWidgetItem*>
        signalUpdateHeader();

private:
    CFListWidgetPriv* m_priv;
    sigc::signal<void, CFListWidgetItem*> m_itemSelectedSignal;
    sigc::signal<void, CFListWidgetItem*> m_itemActivatedSignal;
    sigc::signal<void> m_selectedItemsChangedSignal;

    sigc::signal<void, CFListWidgetItem*> m_foreachSignal;
    sigc::signal<bool, CFListWidgetItem*> m_filterSignal;
    sigc::signal<int, CFListWidgetItem*, CFListWidgetItem*> m_sortSignal;
    sigc::signal<void, CFListWidgetItem*, CFListWidgetItem*>
        m_updateHeaderSignal;
};

CF_NAMESPACE_END

#endif  // __CFLIST_WIDGET_H__
