// Copyright 2017, CDOS.
// All rights reserved.
//
// Author: CDOS Support Team <support_os@sari.ac.cn>
//
// A CFListWidget is a vertical container that contains CFListWidgetItem
// children.
/**
 * \file
 * 列表容器添加项
 */
#ifndef __CF_LISTWIDGETITEM_H__
#define __CF_LISTWIDGETITEM_H__

#include <Gui/CFBin.h>

CF_NAMESPACE_BEGIN

/**
 * \brief 列表容器添加项
 *
 * 专门用于向 CFListWidgetItem 中添加的项，本身可以存放其他容器。
 */
class CFListWidgetItem : public CFBin {
public:
    /**
     * 默认构造函数.
     */
    CFListWidgetItem();

    /**
     * 析构函数.
     *
     * 在 CFListWidgetItem 被销毁时会被自动调用。
     * 在析构函数中进行内存释放等操作。
     */
    virtual ~CFListWidgetItem();

    /**
     * 设置 CFListWidgetItem 的当前头
     *
     * 这只允许 CFListWidget::SlotUpdateHeader 调用。它将替换现有的标题，
     * 并显示在列表框中的行前。
     *
     * @param [in] header 要设置行前的控件
     */
    void setHeader(CFWidget& header);

    /**
     * 如果 CFListWidgetItem 存在头部，移除当前的头部。
     */
    void unsetHeader();

    /**
     * 获取 CFListWidgetItem 的头部控件
     *
     * 如果已经设置了头部，就可以在 CFListWidget::SlotUpdateHeader 中使用此方法
     * 之后会更新它的状态
     *
     * @return 返回 CFListWidgetItem 的 perp
     */
    CFWidget* getHeader();

    /**
     * 获取 CFListWidgetItem 的在 CFListWidget 中的索引。
     *
     * @return 返回此控件的索引;如果没找到就返回-1.
     */
    int getIndex();

    /**
     * 改变控件的状态。
     *
     * 将控件标记为已更改，将导致任何依赖于这个状态的相关发生更新
     * 这将影响排序，过滤和头部。<br>
     * 这通常意味着如果您不完全控制数据模型，那就必须复制影响列表框功能的数据到控件本身。
     * 另一个选择是在任何模型更改时，调用 invalidate_sort() , 但这将消耗更多的内存。
     */
    void changed();

    /**
     * 返回 CFListWidget 容器的子控件是否是当前选中。
     *
     * @return 如果被选中，返回 true
     */
    bool isSelected();

    /**
     * 设置 CFListWidgetItem 是否可以被选择
     *
     * @param [in] selectable 如果为true，标记控件可选择
     */
    void setSelectable(bool selectable = true);

    /**
     * 获取 CFListWidgetItem 是否可选择
     *
     * @return 如果可以被选择返回 true
     */
    bool getSelectable();

    /**
     * 设置 CFListWidgetItem 可激活属性
     *
     * @param [in] activatable 设置可激活属性
     */
    void setActivatable(bool activatable = true);

    /**
     * 获取 CFListWidgetItem 可激活属性
     *
     * @return 返回 CFListWidgetItem 的可激活属性
     */
    bool getActivatable();
};

CF_NAMESPACE_END

#endif  // __CF_LISTWIDGETITEM_H__
