// Copyright 2017, CDOS.
// All rights reserved.
//
// Author: CDOS Support Team <support_os@sari.ac.cn>
//
// A standard menu bar which usually holds CFMenu submenu items.
/**
 * \file
 *  菜单
 */
#ifndef __CF_MENUBAR_H__
#define __CF_MENUBAR_H__

#include "Gui/CFMenuShell.h"
#include "Gui/CFEnums.h"

CF_NAMESPACE_BEGIN
/**
 * \brief 一种标准的菜单
 *
 * 用于放置菜单项的菜单
 */
class CFMenuBar : public CFMenuShell {
public:
    /**
     * 默认构造函数.
     */
    CFMenuBar();

    /**
     * 析构函数.
     *
     * 在 CFMenuBar 被销毁时会被自动调用。
     * 在析构函数中进行内存释放等操作。
     */
    virtual ~CFMenuBar();

    /**
     * 检测 CFMenuBar 的放置方向
     *
     * @see setPackDirection()
     *
     * @return 返回 CFMenuBar 的放置方向
     */
    CFPackDirection getPackDirection();

    /**
     * 设置 CFMenuBar 的控件摆放方向
     *
     * @param [in] packDir 控件放置的方向
     */
    void setPackDirection(CFPackDirection pack_dir);

    /**
     * 检测 CFMenuBar 子容器的放置方向
     *
     * @see setChildPackDirection()
     *
     * @return 返回 CFMenuBar 子容器的放置方向
     */
    CFPackDirection getChildPackPirection();

    /**
     * 设置 CFMenuBar 的子容器的放置方向
     *
     * @param [in] packPir 子容器的放置方向
     */
    void setChildPackPirection(CFPackDirection pack_dir);
};

CF_NAMESPACE_END
#endif  // __CF_MENUBAR_H__
