#ifndef __CF_MENUITEM_H__
#define __CF_MENUITEM_H__

#include <Gui/CFBin.h>

CF_NAMESPACE_BEGIN

class CFMenu;
class CFMenuItem : public CFBin {
public:
    explicit CFMenuItem();
    CFMenuItem(CFWidget& widget);

    CFMenuItem(const Glib::ustring& label, bool mnemonic = false);

    virtual ~CFMenuItem();

    void setSubmenu(CFMenu& submenu);

    void unsetSubmenu();

    CFMenu* getSubmenu();

    bool hasSubmenu();

    void select();

    void deselect();

    void activate();

    void toggleSizeRequest(int& requisition);

    void toggleSizeAllocate(int allocation);

    void setRightJustified(bool right_justified = true);

    bool getRightJustified();

    void setAccelPath(const Glib::ustring& accel_path);

    void unsetAccelPath();

    Glib::ustring getAccelPath();

    void setLabel(const Glib::ustring& label);

    Glib::ustring getLabel();

    void setUseUnderline(bool setting = true);

    bool getUseUnderline();

    void setReserveIndicator(bool reserve = true);

    bool getReserveIndicator();

public:
    sigc::signal<void> signalActivate();

    sigc::signal<void> signalActivateItem();

    sigc::signal<void, int*> signalToggleSizeRequest();

    sigc::signal<void, int> signalToggleSizeAllocate();

    sigc::signal<void> signalSelect();

    sigc::signal<void> signalDeselect();

protected:
    virtual void onRealObjectInit();
    virtual void onRealObjectFinalize();

    virtual void onActivate();

    virtual void onActivateItem();

    virtual void onToggleSizeRequest(int* requisition);

    virtual void onToggleSizeAllocate(int allocation);

    virtual void onSelect();

    virtual void onDeselect();

private:
    sigc::signal<void> m_activateSignal;
    sigc::signal<void> m_activateItemSignal;
    sigc::signal<void, int*> m_toggleSizeRequestSignal;
    sigc::signal<void, int> m_toggleSizeAllocSignal;
    sigc::signal<void> m_selectSignal;
    sigc::signal<void> m_deselectSignal;
};

CF_NAMESPACE_END

#endif  // __CF_MENUITEM_H__
