#ifndef __CF_MENUSHELL_H__
#define __CF_MENUSHELL_H__

#include <Gui/CFContainer.h>
#include <giomm.h>

CF_NAMESPACE_BEGIN

class CFMenuItem;
class CFWindow;
class CFMenuShellPrivate;
class CFMenuShell : public CFContainer {
public:
    ~CFMenuShell();

    void append(CFMenuItem& child);

    void prepend(CFMenuItem& child);

    void insert(CFMenuItem& child, int position);

    void selectItem(CFMenuItem& menu_item);

    void deselect();

    void activateItem(CFMenuItem& menu_item, bool force_deactivate = false);

    void selectFirst(bool search_sensitive = true);

    void deactivate();

    void cancel();

    void accelerate(CFWindow& window);

    void accelerate(CFWidget& parent);

    bool getTakeFocus();

    void setTakeFocus(bool take_focus = true);

    CFWidget* getSelectedItem();

    CFWidget* getParentShell();

    void bindModel(const Glib::RefPtr<Gio::MenuModel>& model,
                   const Glib::ustring& action_namespace,
                   bool with_separators);

    void bindModel(const Glib::RefPtr<Gio::MenuModel>& model,
                   bool with_separators);

public:
    sigc::signal<void> signalDeactivate();

    sigc::signal<void> signalSelectionDone();

    sigc::signal<bool, int> signalMoveSelected();

    sigc::signal<void, CFWidget*, int> signalInsert();

protected:
    virtual void onRealObjectInit();
    virtual void onRealObjectFinalize();

    virtual void onDeactivate();

    virtual void onSelectionDone();

    virtual bool onMoveSelected(int distance);

    CFMenuShell();

private:
    sigc::signal<void> m_deactivateSignal;
    sigc::signal<void> m_selectionDoneSignal;
    sigc::signal<bool, int> m_moveSelectedSignal;
    sigc::signal<void, CFWidget*, int> m_insertSignal;
    CFMenuShellPrivate* m_priv;
};

CF_NAMESPACE_END

#endif  // __CF_MENUSHELL_H__