// Copyright 2017, CDOS.
// All rights reserved.
//
// Author: CDOS Support Team <support_os@sari.ac.cn>
//
// CFRange is a base class for widgets which visullize an adjustment.
/** 
 * \file
 * 范围控件
 */
#ifndef __CF_RANGE_H__
#define __CF_RANGE_H__

#include <Gui/CFWidget.h>

CF_NAMESPACE_BEGIN

/**
 * \brief CFRange 用于可视化调节控件的基类
 */
class CFRange : public CFWidget {
public:
    /**
     * 析构函数.
     *
     * 在 CFRange 被销毁时会被自动调用。
     * 在析构函数中进行内存释放等操作。
     */
    virtual ~CFRange();

    /**
     * 设置 CFRange 的步长和翻页长度
     *
     * @param [in] step 每次移动的距离
     * @param [in] page 翻页跳转的距离
     */
    void setIncrements(double step, double page);

    /**
     * 设置 CFRange 的范围
     *
     * @param [in] min 最小值
     * @param [in] max 最大值
     */
    void setRange(double min, double max);

    /**
     * 设置 CFRange 的值
     *
     * @param [in] value 控件值
     */
    void setValue(double value);

    /**
     * 获取 CFRange 的值
     *
     * @return 返回 CFRange 的值
     */
    double getValue();

    /**
     * 设置 CFRange 的设置四舍五入的精确度
     *
     * @param [in] round_digits 数字的精确度 或者 -1
     */
    void setRoundDigits(int round_digits);

    /**
     * 获取 CFRange 的精确度
     *
     * @return 返回 CFRange 的四舍五入的精确度
     */
    int getRoundDigits();

public:
    /**
     * 槽函数类型：<br>
     *    void on_my_value_changed();
     *
     * 当值发生改变时发送
     */
    sigc::signal<void> signalValueChanged();

protected:
    CFRange();
    virtual void onRealObjectInit();
    virtual void onRealObjectFinalize();

    virtual void onChangeValue();

private:
    sigc::signal<void> m_valueChangedSignal;
};

CF_NAMESPACE_END

#endif  // __CF_RANGE_H__