// Copyright 2017, CDOS.
// All rights reserved.
//
// Author: CDOS Support Team <support_os@sari.ac.cn>
//
// CFScale is base class for widgets which visualize an adjustment.
/**
 * \file
 * 从某个范围内选定一个值的滑动控件。
 */
#ifndef __CF_SCALE_H__
#define __CF_SCALE_H__

#include "Gui/CFRange.h"

CF_NAMESPACE_BEGIN

/**
 * \brief CFScale 是使用一个滑块来选择一个数值。
 *
 * CFScale 是用于选择数值的滑块控件。 要使用它，除了 CFScale 本身的方法之外，
 * 你可能想要调查其基类 CFRange 上的方法。要设置刻度的值，通常使用set_value()。
 * 为了检测变化值，你通常会使用signal_value_changed()。
 */
class CFScale : public CFRange {
public:
    /** @construct_default */
    CFScale();

    /**
     * 构造函数
     *
     * 创建一个 CFScale 类型的实例
     *
     * @param [in] orientation 控件的方向
     */
    CFScale(CFOrientation orientation);

    /**
     * 析构函数.
     *
     * 在 CFScale 被销毁时会被自动调用。
     * 在析构函数中进行内存释放等操作。
     */
    ~CFScale();

    /**
     * 设置 CFScale 的设置数值
     *
     * @param [in] digits 设置数值
     */
    void setDigits(int digits);

    /**
     * 获取 CFScale 的数值
     *
     * @return 返回 CFScale 的数值
     */
    int getDigits();

    /**
     * 设置 CFScale 是否在滑块旁，以字符串形式显示数值
     *
     * @param [in] draw_value 是否显示的布尔值
     */
    void setDrawValue(bool draw_value = true);

    /**
     * 获取 CFScale 是否跟随滑块显示数值
     *
     * @return 返回 CFScale 的draw_value显示状态
     */
    bool getDrawValue();

    /**
     * 为控件添加标记
     *
     * @param [in] value 值
     * @param [in] position 方向
     * @param [in] markup 标记内容
     */
    void addMark(double value,
                  CFPositionType position,
                  const Glib::ustring& markup);

    /**
     * 清除 CFScale 标记
     */
    void clearMark();

    /**
     * 设置 CFScale 的滑槽是否反掉转180度：默认是从左到右，从上到下
     *
     * @param [in] setting 是否掉转
     */
    void setInverted(bool setting = true);
};

CF_NAMESPACE_END

#endif  // __CF_SCALE_H__
