// Copyright 2017, CDOS.
// All rights reserved.
//
// Author: CDOS Support Team <support_os@sari.ac.cn>
//
// CFVolumeItem is a slider class.

/** \file
 *  声音按钮项控件
 */

#ifndef __CF_VOLUMEBUTTON_ITEM_H__
#define __CF_VOLUMEBUTTON_ITEM_H__

#include "Gui/CFScale.h"
#include "Gui/CFBox.h"
#include "Gui/CFLabel.h"
#include "Gui/CFImage.h"
#include "Gui/CFFixed.h"
#include "Gui/CFCheckButton.h"
#include <Core/CFTypes.h>

CF_NAMESPACE_BEGIN

/** \addtogroup 结构与枚举类型定义
   @{ */

/**
 * \enum CFVolumeButtonItemType
 *  声音按钮项的类型
 */
enum CFVolumeButtonItemType {
    kVolumeItem = 0,  ///< 声音类型，代表输出
    kMicrophoneItem  ///< 麦克风类型，表示输入
};

/** @} */

/**
 * \brief CFVolumeButtonItem 控件会以矩形区域来组织其所容纳的控件。
 *
 * 在构造函数的参数中，orientation设定滚动条的方向，type设定它所呈现的类型是输出和输入。
 * 每种类型都包括控件头部（文本和图标），滚动条，和静音单选按钮组成。
 */
class CFVolumeButtonItem : public CFBox {
public:
    /**
     * @construct_other{CFVolumeButtonItem}
     *
     * @cfparam{orientation, 控件的方向}
     * @cfparam{type, 控件的类型}
     */
    CFVolumeButtonItem(CFOrientation orientation, CFVolumeButtonItemType type);

    /**
     * @destruct
     *
     * @destruct_when{CFVolumeButtonItem}
     */
    ~CFVolumeButtonItem();

    /* setter and getter */
    /**
     * 获取音量按钮控件项的类型
     *
     * 类型主要包括 kVolumeItem 和 kMicrophoneItem，类型设定于初始化。
     *
     * @return 返回 CFVolumeButtonItem 的类型
     */
    CFVolumeButtonItemType getItemType();

    /**
     * @set_description{CFVolumnButtonItem, 控件头部图标}
     * 根据设定音量来改变对应的图标
     *
     * @cfparam{current_val, 设定的音量值}
     */
    void setTitleIcons(int current_val);  // no get titleIcons

    /**
     * 设置 CFVolumeButtonItem 的值
     *
     * @param [in] value 设定控件的值（同步更新包括头部的文本，图标类型，滚动条）
     */
    void setSliderValue(double value);

    /**
     * 获取 CFVolumeButtonItem 的值
     *
     * @return 返回 CFVolumeButtonItem 的值
     */
    double getSliderValue();

    /**
     * 获取 CFVolumeButtonItem 的静音按钮的勾选状态
     *
     * @return 返回 CFVolumeButtonItem 的勾选状态
     */
    bool getMuteStatus();

    /**
     * 设置 CFVolumeButtonItem 的静音按钮的勾选状态
     *
     * @param [in] is_muted 静音按钮的勾选状态
     */
    void setMuteStatus(bool is_muted);

    /**
     * 设置 CFVolumeButtonItem 的静音按钮标签
     *
     * 无获取标签接口
     *
     * @param [in] label 静音按钮标签字符串
     */
    void setMuteLabel(std::string label);  // no get label

    /**
     * 设置 CFVolumeButtonItem 的输入控件的显示状态
     *
     * @param [in] is_show 是否显示输入控件
     */
    void showMicrophone(bool is_show);  // not get

private:
    // signal
    void onScaleChanged();
    void onMuted();

private:
    CFInt32 m_title_text_width;
    CFInt32 m_title_icons_size;

    CFVolumeButtonItemType m_type;
    CFLabel m_title_val;  // icons and text
    CFImage m_title_icons;
    CFFixed m_title;
    CFBox m_container;  // container
    CFScale m_slider;
    CFFixed m_slider_fixed;
    CFCheckButton m_mute;
    CFFixed m_mute_fixed;
};

CF_NAMESPACE_END

#endif  // __CF_VOLUMEBUTTON_ITEM_H__
