#ifndef __CFLUNAR_H__ 
#define __CFLUNAR_H__

#include <Core/CFTypes.h>

extern const CFUInt16 LUNAR_START_YEAR;
extern const CFUInt16 LUNAR_END_YEAR;

class CFLunar {
private:
    CFUInt16 m_year, m_month, m_day;
    void l_initData();
    static void l_calcLunarDate(CFUInt16 &iYear, CFUInt16 &iMonth ,
		    CFUInt16 &iDay,long iSpanDays);
    static CFUInt16 l_getLunarHolDay(CFUInt16 iYear, CFUInt16 iMonth, 
		    CFUInt16 iDay);

public:
    CFLunar(CFUInt16 iYear, CFUInt16 iMonth, CFUInt16 iDay);
    CFLunar(); 
    CFUInt16 getYear() {return m_year;}
    CFUInt16 getMonth() {return m_month;}
    CFUInt16 getDay() {return m_day;}
   
    void getDate(CFUInt16 &iYear, CFUInt16 &iMonth, CFUInt16 &iDay);
    int setDate(CFUInt16 iYear, CFUInt16 iMonth, CFUInt16 iDay);
      
    static int isLeapYear(CFUInt16 iYear) {return !(iYear%4)&&(iYear%100) || !(iYear%400);}
    static CFUInt16 weekDay(CFUInt16 iYear, CFUInt16 iMonth, CFUInt16 iDay);
    static void formatWeekDay (CFUInt16 iYear, CFUInt16 iMonth, CFUInt16 iDay, char *pBuffer);
    static CFUInt16 monthDays(CFUInt16 iYear, CFUInt16 iMonth);

    static long lunarMonthDays(CFUInt16 iLunarYear, CFUInt16 iLunarMonth);
    static CFUInt16 lunarYearDays(CFUInt16 iLunarYear);

    static CFUInt16 getLeapMonth(CFUInt16 iLunarYear);
    static bool getFormatLeapMonth (CFUInt16 iLunarYear, char *pBuffer);

    static void formatLunarYear(CFUInt16 iLunarYear, char *pBuffer);
    static void formatLunarMonth(CFUInt16 iLunarMonth, char *pBuffer);
    static void formatLunarDay(CFUInt16 iLunarDay, char *pBuffer);

    static long calcDateDiff(CFUInt16 iEndYear, CFUInt16 iEndMonth, 
		    CFUInt16 iEndDay, CFUInt16 iStartYear = LUNAR_START_YEAR,
		    CFUInt16 iStartMonth = 1, CFUInt16 iStartDay = 1);

    static void getLunarDate(CFUInt16 iYear, CFUInt16 iMonth, 
		    CFUInt16 iDay, CFUInt16 &iLunarYear,
		    CFUInt16 &iLunarMonth, CFUInt16 &iLunarDay);
    static void getFormatLunarDate (CFUInt16 iYear, CFUInt16 iMonth, CFUInt16 iDay, char *pBuffer);

    static bool getSolarTerm (CFUInt16 iYear, CFUInt16 iMonth, CFUInt16 iDay, char *pBuffer);
}; 
#endif //__CFLUNAR_H__
